Coverage for manage.py: 54%

# Coverage for manage.py : 54%

## 13 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1#!/usr/bin/env python

2 import os

3 import sys

4

5 if __name__ == "__main__":

6 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "project.settings")

7 try:

8 from django.core.management import execute_from_command_line

9 except ImportError:

10 # The above import may fail for some other reason. Ensure that the

11 # issue is really that Django is missing to avoid masking other

12 # exceptions on Python 2.

13 try:

14 import django # noqa

15 except ImportError:

16 raise ImportError(

17 "Couldn't import Django. Are you sure it's installed and "

18 "available on your PYTHONPATH environment variable? Did you "

19 "forget to activate a virtual environment?"

20 )

21 raise

22 execute_from_command_line(sys.argv)